# [Experimental] Model Runner V2

This directory contains the new model runner which is under active development.

please see [Model Runner V2](https://github.com/vllm-project/vllm-ascend/issues/5208)
to get specific plans.
